@@ -1,13 +1,14 @@
 import re
 
 from django.db.models import EmailField
+from django.db.models.loading import get_models
 
 field_replacers = {
-    'AutoField': None,
-    'ForeignKey': None,
-    'ManyToManyField': None,
-    'OneToOneField': None,
-    'SlugField': None, # we probably don't want to change slugs
+    'AutoField': '"SKIP"',
+    'ForeignKey': '"SKIP"',
+    'ManyToManyField': '"SKIP"',
+    'OneToOneField': '"SKIP"',
+    'SlugField': '"SKIP"', # we probably don't want to change slugs
     'DateField': '"date"',
     'DateTimeField': '"datetime"',
     'BooleanField': '"bool"',
@@ -16,6 +17,7 @@ field_replacers = {
     'SmallIntegerField': '"small_integer"',
     'PositiveIntegerField': '"positive_integer"',
     'PositiveSmallIntegerField': '"positive_small_integer"',
+    'DecimalField': '"decimal"',
 }
 
 # NB - order matters. 'address' is more generic so should be at the end.
@@ -36,6 +38,7 @@ charfield_replacers = [
     (r'(\b|_)zipcode\d*', '"zip_code"'),
     (r'(\b|_)zip_code\d*', '"zip_code"'),
     (r'(\b|_)telephone\d*', '"phonenumber"'),
+    (r'(\b|_)phone\d*', '"phonenumber"'),
     (r'(\b|_)mobile\d*', '"phonenumber"'),
     (r'(\b|_)tel\d*\b', '"phonenumber"'),
     (r'(\b|_)state\d*\b', '"state"'),
@@ -47,6 +50,11 @@ def get_replacer_for_field(field):
     if isinstance(field, EmailField):
         return '"email"'
 
+    # Use choices, if available.
+    choices = getattr(field, 'choices', None)
+    if choices is not None and len(choices) > 0:
+        return '"choice"'
+
     field_type = field.get_internal_type()
     if field_type == "CharField" or field_type == "TextField":
         # Guess by the name
@@ -77,7 +85,6 @@ def get_replacer_for_field(field):
     return r
 
 attribute_template = "        ('%(attname)s', %(replacer)s),"
-skipped_template   = "         # Skipping field %s"
 class_template = """
 class %(modelname)sAnonymizer(Anonymizer):
 
@@ -103,11 +110,22 @@ def create_anonymizer(model):
 
     for f in fields:
         replacer = get_replacer_for_field(f)
-        if replacer is None:
-            attributes.append(skipped_template % f.attname)
-        else:
-            attributes.append(attribute_template % {'attname': f.attname,
-                                                    'replacer': replacer })
+        attributes.append(attribute_template % {'attname': f.attname,
+                                                'replacer': replacer })
     return class_template % {'modelname':model.__name__,
                              'attributes': "\n".join(attributes) }
 
+
+def create_anonymizers_module(app):
+    model_names = []
+    imports = []
+    output = []
+    output.append("")
+    imports.append("from anonymizer import Anonymizer")
+    for model in get_models(app):
+        model_names.append(model.__name__)
+        output.append(create_anonymizer(model))
+
+    imports.insert(0, "from %s import %s" % (app.__name__, ", ".join(model_names)))
+
+    return "\n".join(imports) + "\n".join(output)
