@@ -2,47 +2,52 @@
 
 varchar = lambda anon, obj, field, val: anon.faker.varchar(field=field)
 varchar.__doc__ = """
-Produces random data for a varchar field.
+Returns random data for a varchar field.
 """
 
 bool = lambda anon, obj, field, val: anon.faker.bool(field=field)
 bool.__doc__ = """
-Produces a random boolean value (True/False)
+Returns a random boolean value (True/False)
 """
 
 integer = lambda anon, obj, field, val: anon.faker.integer(field=field)
 integer.__doc__ = """
-Produces a random integer (for a Django IntegerField)
+Returns a random integer (for a Django IntegerField)
 """
 
 positive_integer = lambda anon, obj, field, val: anon.faker.positive_integer(field=field)
 positive_integer.__doc__ = """
-Produces a random positive integer (for a Django PositiveIntegerField)
+Returns a random positive integer (for a Django PositiveIntegerField)
 """
 
 small_integer = lambda anon, obj, field, val: anon.faker.small_integer(field=field)
 small_integer.__doc__ = """
-Produces a random small integer (for a Django SmallIntegerField)
+Returns a random small integer (for a Django SmallIntegerField)
 """
 
 positive_small_integer = lambda anon, obj, field, val: anon.faker.positive_small_integer(field=field)
 positive_small_integer.__doc__ = """
-Produces a positive small random integer (for a Django PositiveSmallIntegerField)
+Returns a positive small random integer (for a Django PositiveSmallIntegerField)
 """
 
 datetime = lambda anon, obj, field, val: anon.faker.datetime(field=field)
 datetime.__doc__ = """
-Produces a random datetime
+Returns a random datetime
 """
 
 date = lambda anon, obj, field, val: anon.faker.date(field=field)
 date.__doc__ = """
-Produces a random date
+Returns a random date
+"""
+
+decimal = lambda anon, obj, field, val: anon.faker.decimal(field=field)
+decimal.__doc__ = """
+Returns a random decimal
 """
 
 uk_postcode = lambda anon, obj, field, val: anon.faker.uk_postcode(field=field)
 uk_postcode.__doc__ = """
-Produces a random UK postcode (not necessarily valid, but it will look like one).
+Generates a random UK postcode (not necessarily valid, but it will look like one).
 """
 
 uk_country = lambda anon, obj, field, val: anon.faker.uk_country(field=field)
@@ -52,51 +57,51 @@ Returns a randomly selected country that is part of the UK
 
 uk_county = lambda anon, obj, field, val: anon.faker.uk_county(field=field)
 uk_county.__doc__ = """
-Returns a random selected county from the UK
+Returns a randomly selected county from the UK
 """
 
 username = lambda anon, obj, field, val: anon.faker.username(field=field)
 username.__doc__ = """
-Produces a randomly generated username
+Generates a random username
 """
 
 first_name = lambda anon, obj, field, val: anon.faker.first_name(field=field)
 first_name.__doc__ = """
-Produces a randomly generated first name
+Returns a random first name
 """
 
 last_name = lambda anon, obj, field, val: anon.faker.last_name(field=field)
 last_name.__doc__ = """
-Produces a randomly generated second name
+Returns a random second name
 """
 
 name = lambda anon, obj, field, val: anon.faker.name(field=field)
 name.__doc__ = """
-Produces a randomly generated full name (using first name and last name)
+Generates a random full name (using first name and last name)
 """
 
 email = lambda anon, obj, field, val: anon.faker.email(field=field)
 email.__doc__ = """
-Produces a randomly generated email address.
+Generates a random email address.
 """
 full_address = lambda anon, obj, field, val: anon.faker.full_address(field=field)
 full_address.__doc__ = """
-Produces a randomly generated full address, using newline characters between the lines.
+Generates a random full address, using newline characters between the lines.
 Resembles a US address
 """
 phonenumber = lambda anon, obj, field, val: anon.faker.phonenumber(field=field)
 phonenumber.__doc__ = """
-Produces a randomly generated US-style phone number
+Generates a random US-style phone number
 """
 
 street_address = lambda anon, obj, field, val: anon.faker.street_address(field=field)
 street_address.__doc__ = """
-Produces a randomly generated street address - the first line of a full address
+Generates a random street address - the first line of a full address
 """
 
 city = lambda anon, obj, field, val: anon.faker.city(field=field)
 city.__doc__ = """
-Produces a randomly generated city name. Resembles the name of US/UK city.
+Generates a random city name. Resembles the name of US/UK city.
 """
 
 state = lambda anon, obj, field, val: anon.faker.state(field=field)
@@ -111,12 +116,12 @@ Returns a randomly generated US zip code (not necessarily valid, but will look l
 
 company = lambda anon, obj, field, val: anon.faker.company(field=field)
 company.__doc__ = """
-Returns a randomly generated company name
+Generates a random company name
 """
 
 lorem = lambda anon, obj, field, val: anon.faker.lorem(field=field)
 lorem.__doc__ = """
-Returns a paragraph of lorem ipsum text
+Generates a paragraph of lorem ipsum text
 """
 
 similar_datetime = lambda anon, obj, field, val: anon.faker.datetime(field=field, val=val)
@@ -131,7 +136,12 @@ Returns a date that is within plus/minus two years of the original date
 
 similar_lorem = lambda anon, obj, field, val: anon.faker.lorem(field=field, val=val)
 similar_lorem.__doc__ = """
-Produces lorem ipsum text with the same length and same pattern of linebreaks as
-the original. If the original often takes a standard form (e.g. a single word
+Generates lorem ipsum text with the same length and same pattern of linebreaks
+as the original. If the original often takes a standard form (e.g. a single word
 'yes' or 'no'), this could easily fail to hide the original data.
 """
+
+choice = lambda anon, obj, field, val: anon.faker.choice(field=field)
+choice.__doc__ = """
+Randomly chooses one of the choices set on the field.
+"""
